# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "bactec_mgit"


def test_decode_mgit_gnd_specimen_not_tested(self):
    date = None
    worklist = self.decode(
        """
        H|\\^&|||Becton Dickinson|7 Loveton Circle^Sparks^MD^21152||410 316-4000||||P|V1.00|19981019184200
        P|1
        O|1|0970038018||^^^MGIT_960_GND
        R|1|^^^GND_MGIT^430109967349|INST_ONGOING^0|||||P|||||MGIT960^^42^1^B/A01
        L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "B/A01",
                "type": "patient",
                "sample_id": "0970038018",
                "results": [
                    {
                        "code": "GND_MGIT",
                        "date": date,
                        "value": "INST_ONGOING",
                        "instrument": "MGIT960-1",
                    },
                    {
                        "code": "BOTTLE_ID",
                        "date": date,
                        "instrument": "MGIT960-1",
                        "value": "430109967349",
                    },
                    {
                        "code": "BOTTLE_RACK",
                        "date": date,
                        "instrument": "MGIT960-1",
                        "value": "B/A01",
                    },
                    {"code": "GROWTH_UNITS", "value": "0"},
                    {"code": "GROWTH_TIME", "value": "0"},
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_mgit_gnd_specimen_tested_still_active(self):
    date = datetime.datetime(1996, 5, 7, 11, 54, 14)
    worklist = self.decode(
        """
        H|\\^&|||Becton Dickinson|7 Loveton Circle^Sparks^MD^21152||410 316-4000||||P|V1.00|19981019184200
        P|1
        O|1|0970038018||^^^MGIT_960_GND
        R|1|^^^GND_MGIT^430109967349|INST_ONGOING^123|||||P|||19960502115414|19960507115414|MGIT960^^42^1^B/A01
        L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "B/A01",
                "type": "patient",
                "sample_id": "0970038018",
                "results": [
                    {
                        "code": "GND_MGIT",
                        "date": date,
                        "value": "INST_ONGOING",
                        "instrument": "MGIT960-1",
                    },
                    {
                        "code": "BOTTLE_ID",
                        "date": date,
                        "instrument": "MGIT960-1",
                        "value": "430109967349",
                    },
                    {
                        "code": "BOTTLE_RACK",
                        "date": date,
                        "instrument": "MGIT960-1",
                        "value": "B/A01",
                    },
                    {"code": "INTRODUCE_DATETIME", "value": "1996/05/02 11:54:14"},
                    {"code": "BOTTLE_INTRODUCE_DATETIME", "value": "19960502115414"},
                    {"code": "INTRODUCE_DATE", "value": "1996/05/02"},
                    {"code": "INTRODUCE_TIME", "value": "11:54:14"},
                    {"code": "INTRODUCTION_DATE", "value": "02/05/1996"},
                    {"code": "INTRODUCTION_HEURE", "value": "11:54"},
                    {"code": "DETERMINED_DATETIME", "value": "19960507115414"},
                    {"code": "DETERMINED_DATE", "value": "1996/05/07"},
                    {"code": "DETERMINED_TIME", "value": "11:54:14"},
                    {"code": "DATE_DETERMINATION", "value": "07/05/1996"},
                    {"code": "HEURE_DETERMINATION", "value": "11:54"},
                    {"code": "GROWTH_UNITS", "value": "123"},
                    {"code": "GROWTH_TIME", "value": "120H00"},
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_mgit_gnd_specimen_tested_pos(self):
    date = datetime.datetime(1996, 5, 9, 12, 34, 56)
    worklist = self.decode(
        """
        H|\\^&|||Becton Dickinson|7 Loveton Circle^Sparks^MD^21152||410 316-4000||||P|V1.00|19981019184200
        P|1
        O|1|0970038018||^^^MGIT_960_GND
        R|1|^^^GND_MGIT^430109967349|INST_POSITIVE^1234|||||P|||19960502115414|19960509123456|MGIT960^^42^1^B/A01
        L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "B/A01",
                "type": "patient",
                "sample_id": "0970038018",
                "results": [
                    {
                        "code": "GND_MGIT",
                        "date": date,
                        "value": "INST_POSITIVE",
                        "instrument": "MGIT960-1",
                    },
                    {
                        "code": "BOTTLE_ID",
                        "date": date,
                        "instrument": "MGIT960-1",
                        "value": "430109967349",
                    },
                    {
                        "code": "BOTTLE_RACK",
                        "date": date,
                        "instrument": "MGIT960-1",
                        "value": "B/A01",
                    },
                    {"code": "INTRODUCE_DATETIME", "value": "1996/05/02 11:54:14"},
                    {"code": "BOTTLE_INTRODUCE_DATETIME", "value": "19960502115414"},
                    {"code": "INTRODUCE_DATE", "value": "1996/05/02"},
                    {"code": "INTRODUCE_TIME", "value": "11:54:14"},
                    {"code": "INTRODUCTION_DATE", "value": "02/05/1996"},
                    {"code": "INTRODUCTION_HEURE", "value": "11:54"},
                    {"code": "DETERMINED_DATETIME", "value": "19960509123456"},
                    {"code": "DETERMINED_DATE", "value": "1996/05/09"},
                    {"code": "DETERMINED_TIME", "value": "12:34:56"},
                    {"code": "DATE_DETERMINATION", "value": "09/05/1996"},
                    {"code": "HEURE_DETERMINATION", "value": "12:34"},
                    {"code": "POSITIVITY_DATETIME", "value": "19960509123456"},
                    {"code": "POSITIVITY_DATE", "value": "1996/05/09"},
                    {"code": "POSITIVITE_DATE", "value": "09/05/1996"},
                    {"code": "POSITIVITY_TIME", "value": "12:34:56"},
                    {"code": "POSITIVITE_HEURE", "value": "12:34"},
                    {"code": "TIME_TO_DETECTION_POSITIVITY", "value": "168H40"},
                    {"code": "GROWTH_UNITS", "value": "1234"},
                    {"code": "GROWTH_TIME", "value": "168H40"},
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_mgit_gnd_specimen_tested_neg(self):
    date = datetime.datetime(1996, 5, 9, 12, 34, 56)
    worklist = self.decode(
        """
        H|\\^&|||Becton Dickinson|7 Loveton Circle^Sparks^MD^21152||410 316-4000||||P|V1.00|19981019184200
        P|1
        O|1|0970038018||^^^MGIT_960_GND
        R|1|^^^GND_MGIT^430109967349|INST_NEGATIVE^12|||||P|||19960502115414|19960509123456|MGIT960^^42^1^1B/A01
        L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "1B/A01",
                "type": "patient",
                "sample_id": "0970038018",
                "results": [
                    {
                        "code": "GND_MGIT",
                        "date": date,
                        "value": "INST_NEGATIVE",
                        "instrument": "MGIT960-1",
                    },
                    {
                        "code": "BOTTLE_ID",
                        "date": date,
                        "instrument": "MGIT960-1",
                        "value": "430109967349",
                    },
                    {
                        "code": "BOTTLE_RACK",
                        "date": date,
                        "instrument": "MGIT960-1",
                        "value": "1B/A01",
                    },
                    {"code": "INTRODUCE_DATETIME", "value": "1996/05/02 11:54:14"},
                    {"code": "BOTTLE_INTRODUCE_DATETIME", "value": "19960502115414"},
                    {"code": "INTRODUCE_DATE", "value": "1996/05/02"},
                    {"code": "INTRODUCE_TIME", "value": "11:54:14"},
                    {"code": "INTRODUCTION_DATE", "value": "02/05/1996"},
                    {"code": "INTRODUCTION_HEURE", "value": "11:54"},
                    {"code": "DETERMINED_DATETIME", "value": "19960509123456"},
                    {"code": "DETERMINED_DATE", "value": "1996/05/09"},
                    {"code": "DETERMINED_TIME", "value": "12:34:56"},
                    {"code": "DATE_DETERMINATION", "value": "09/05/1996"},
                    {"code": "HEURE_DETERMINATION", "value": "12:34"},
                    {"code": "GROWTH_UNITS", "value": "12"},
                    {"code": "GROWTH_TIME", "value": "168H40"},
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_mgit_ast_specimen_completed_tested(self):
    date = datetime.datetime(1996, 5, 2, 11, 54, 14)
    self.configure(bactec_hour_min_sep="h")
    worklist = self.decode(
        """
        H|\\^&|||Becton Dickinson|7 Loveton Circle^Sparks^MD^21152||410 316-4000||||P|V1.00|19981019184200
        P|1
        O|1|0970038018^1||^^^MGIT_960_AST
        R|1|^^^AST_MGIT^439309967349^EMB^5.0^ug/ml|INST_COMPLETE^1234^R|||||P|||19960502115414|19960502115414|MGIT960^^^13^B/A02
        R|2|^^^AST_MGIT^439309967349^RIF^1.0^ug/ml|INST_COMPLETE^12^S|||||P|||19960502115414|19960502115414|MGIT960^^^13^B/A03
        L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "0970038018",
                "results": [
                    {"code": "EMB_RACK", "value": "B/A02"},
                    {"code": "EMB_GROWTH_UNITS", "value": "1234"},
                    {"code": "EMB_GROWTH_TIME", "value": "00h00"},
                    {"code": "EMB_CONCENTRATION", "value": "5.0"},
                    {"code": "EMB_SENSITIVITY", "value": "R"},
                    {"code": "EMB_UNITS", "value": "ug/ml"},
                    {"code": "RIF_RACK", "value": "B/A03"},
                    {"code": "RIF_GROWTH_UNITS", "value": "12"},
                    {"code": "RIF_GROWTH_TIME", "value": "00h00"},
                    {"code": "RIF_CONCENTRATION", "value": "1.0"},
                    {"code": "RIF_SENSITIVITY", "value": "S"},
                    {"code": "RIF_UNITS", "value": "ug/ml"},
                    {
                        "code": "AST_MGIT",
                        "date": date,
                        "instrument": "MGIT960-13",
                        "value": [
                            {
                                "sub_code": "1",
                                "antibiogram": [
                                    {
                                        "antibiotic": "A_EMB",
                                        "concentration": "5.0",
                                        "sensitivity": "R",
                                        "units": "ug/ml",
                                    },
                                    {
                                        "antibiotic": "A_RIF",
                                        "concentration": "1.0",
                                        "sensitivity": "S",
                                        "units": "ug/ml",
                                    },
                                ],
                            }
                        ],
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_mgit_ast_specimen_completed_tested_bis(self):
    date = datetime.datetime(1998, 10, 20, 14, 50, 00)
    worklist = self.decode(
        """
        H|\\^&|||Becton Dickinson|||||||| V1.00 |19981019184200
        P|1||PatId123
        O|1|Acc123||^^^MGIT_960_AST
        R|1|^^^AST_MGIT^439400001234^P^0.5^ug/ml|INST_COMPLETE^105^S||||||||19981019153400|19981020145000|MGIT960^^42^3^ B/A13
        R|2|^^^AST_MGIT^439400001234^AMX^0.5^ug/ml|INST_COMPLETE^142^I||||||||19981019153400|19981020145000|MGIT960^^42^3^ B/A14
        R|3|^^^AST_MGIT^439400001234^AM^0.5^ug/ml|INST_COMPLETE^130^R||||||||19981019153400|19981020145000|MGIT960^^42^3^B/A15
        L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "Acc123",
                "results": [
                    {"code": "P_RACK", "value": " B/A13"},
                    {"code": "P_GROWTH_UNITS", "value": "105"},
                    {"code": "P_GROWTH_TIME", "value": "23H16"},
                    {"code": "P_CONCENTRATION", "value": "0.5"},
                    {"code": "P_SENSITIVITY", "value": "S"},
                    {"code": "P_UNITS", "value": "ug/ml"},
                    {"code": "AMX_RACK", "value": " B/A14"},
                    {"code": "AMX_GROWTH_UNITS", "value": "142"},
                    {"code": "AMX_GROWTH_TIME", "value": "23H16"},
                    {"code": "AMX_CONCENTRATION", "value": "0.5"},
                    {"code": "AMX_SENSITIVITY", "value": "I"},
                    {"code": "AMX_UNITS", "value": "ug/ml"},
                    {"code": "AM_RACK", "value": "B/A15"},
                    {"code": "AM_GROWTH_UNITS", "value": "130"},
                    {"code": "AM_GROWTH_TIME", "value": "23H16"},
                    {"code": "AM_CONCENTRATION", "value": "0.5"},
                    {"code": "AM_SENSITIVITY", "value": "R"},
                    {"code": "AM_UNITS", "value": "ug/ml"},
                    {
                        "code": "AST_MGIT",
                        "date": date,
                        "instrument": "MGIT960-3",
                        "value": [
                            {
                                "sub_code": "",
                                "antibiogram": [
                                    {
                                        "antibiotic": "A_P",
                                        "concentration": "0.5",
                                        "sensitivity": "S",
                                        "units": "ug/ml",
                                    },
                                    {
                                        "antibiotic": "A_AMX",
                                        "concentration": "0.5",
                                        "sensitivity": "I",
                                        "units": "ug/ml",
                                    },
                                    {
                                        "antibiotic": "A_AM",
                                        "concentration": "0.5",
                                        "sensitivity": "R",
                                        "units": "ug/ml",
                                    },
                                ],
                            }
                        ],
                    },
                ],
            }
        ],
    }
    assert worklist == expected
