# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

from driverng import Worklist

parser_class = "biorad"


def test_encode_control(self):
    message = self.result_control()
    assert (
        message
        == """
    A|INST|CQ123456|1|20110506|12:14|42|
    B|INST|CQ123456|1|20110506|12:13|4.40|REAGENT
    A|INST|CQ123488|1|20110506|12:14|4|
    """
    )


def test_encode_control_message_v1(self):
    worklist = Worklist(
        [
            {
                "sample_id": "CQ123456",
                "control_level": "1",
                "results": [
                    {
                        "code": "A",
                        "date": datetime.datetime(2011, 5, 6, 12, 14),
                        "instrument": "INST",
                        "value": "42",
                    },
                    {
                        "code": "B",
                        "date": datetime.datetime(2011, 5, 6, 12, 13),
                        "instrument": "INST",
                        "value": "4.40",
                        "reagent": "REAGENT",
                    },
                ],
            }
        ]
    )

    message = self.parser.to_string(self.parser.get_order_message(worklist, context={}))
    assert message == (
        "A|INST|CQ123456|1|20110506|12:14|42|\n"
        "B|INST|CQ123456|1|20110506|12:13|4.40|REAGENT"
    )


def test_decode_control(self):
    worklist = self.decode(
        """
    A|INST|CQ123456|1|20110506|12:14|42|
    B|INST|CQ123456|1|20110506|12:13|4.40|REAGENT
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "control_lot": "CQ123456",
                "sample_id": "CQ123456",
                "type": "control",
                "results": [
                    {
                        "code": "A",
                        "date": datetime.datetime(2011, 5, 6, 12, 14),
                        "instrument": "INST",
                        "value": "42",
                    },
                    {
                        "code": "B",
                        "date": datetime.datetime(2011, 5, 6, 12, 13),
                        "instrument": "INST",
                        "lots": [{"lot": "REAGENT", "type": "reagent"}],
                        "value": "4.40",
                    },
                ],
            }
        ],
    }
    assert worklist == expected
