# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime
import copy

parser_class = "biorad_urt2"


def test_encode_control(self):
    worklist = copy.deepcopy(self.result_control_worklist)
    worklist.samples[0].results.add(
        {
            "code": "D",
            "type": "NM",
            "value": "",
            "date": datetime.datetime(2011, 5, 6, 12, 14),
            "unit": "mV",
            "instrument": "INST",
        }
    )
    message = self.result_control(worklist=worklist)
    assert (
        message
        == """
        H|\\^&|||^1.00|||||||||20130715141912
        O|1|CQ123456
        R|1|^^^A|42|||||||||20110506121400|INST
        R|2|^^^B|4.40||REAGENT|||||||20110506121300|INST
        O|2|CQ123488
        R|1|^^^A|4|||||||||20110506121400|INST
        L|1|N
        """
    )


def test_decode_control(self):
    data = """
    H|\\^&|||BDSim^1.0|||||||||20141031071542
    O|1|A1CTRL
    R|1|^^^A1a^|4.7|%|REAGENT|||||deb||20141029064038|Inst1
    S|1|||||I^^1^352
    R|2|^^^A1a^|5.7|%||||||deb||20141030064038|Inst1
    S|2|||||I^1-2S[W]^1^352
    R|2|^^^A1a^|6.7|%||||||deb||20141031064038|Inst1
    S|3|||||I^1-2.5S^0^352
    L|1|N"""
    worklist = self.decode(data)
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "sample_id": "A1CTRL",
                "control_lot": "A1CTRL",
                "results": [
                    {
                        "code": "A1a",
                        "value": "4.7",
                        "unit": "%",
                        "lots": [{"lot": "REAGENT", "type": "reagent"}],
                        "flags": [],
                        "date": datetime.datetime(2014, 10, 29, 6, 40, 38),
                        "instrument": "Inst1",
                        "status": "1",
                    },
                    {
                        "code": "A1a",
                        "value": "5.7",
                        "unit": "%",
                        "flags": ["1-2S[W]"],
                        "date": datetime.datetime(2014, 10, 30, 6, 40, 38),
                        "instrument": "Inst1",
                        "status": "1",
                    },
                    {
                        "code": "A1a",
                        "value": "6.7",
                        "unit": "%",
                        "flags": ["1-2.5S"],
                        "date": datetime.datetime(2014, 10, 31, 6, 40, 38),
                        "instrument": "Inst1",
                        "status": "0",
                    },
                ],
            }
        ],
    }
    assert worklist == expected

    # On teste aussi avec l'API Message v1
    result_dict = self.parser.get_result_dict(self.parse(data))
    assert result_dict == {}
    qc_result_list = self.parser.get_qc_result_list(self.parse(data))
    expected = [
        {
            "analyseur": "Inst1",
            "date": datetime.datetime(2014, 10, 29, 6, 40, 38),
            "lot": "A1CTRL",
            "lots_calibrations": [],
            "lots_controles": [],
            "lots_reactifs": [{"nom": None, "peremption": None, "ref": "REAGENT"}],
            "resu": "4.7",
            "status": "1",
            "test": "A1a",
        },
        {
            "analyseur": "Inst1",
            "date": datetime.datetime(2014, 10, 30, 6, 40, 38),
            "flags": ["1-2S[W]"],
            "lot": "A1CTRL",
            "lots_calibrations": [],
            "lots_controles": [],
            "lots_reactifs": [],
            "resu": "5.7",
            "status": "1",
            "test": "A1a",
        },
        {
            "analyseur": "Inst1",
            "date": datetime.datetime(2014, 10, 31, 6, 40, 38),
            "flags": ["1-2.5S"],
            "lot": "A1CTRL",
            "lots_calibrations": [],
            "lots_controles": [],
            "lots_reactifs": [],
            "resu": "6.7",
            "status": "0",
            "test": "A1a",
        },
    ]
    assert qc_result_list == expected


def test_decode_flags_multiple(self):
    worklist = self.decode(
        """
    H|\\^&|||^1.00|||||||||20150608122138
    O|1|12046112617
    R|1|^^^12|0.50|||||||||20150608092649|star1tac
    S|1|||||I^1-3ET[A]^1^997002^
    O|2|12047112617
    R|1|^^^12|3|||||||||20150608092715|star1tac
    S|1|||||I^2-2ET[A]\\1-3ET[A]\\R-4ET[A]^1^997003^
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "sample_id": "12046112617",
                "control_lot": "12046112617",
                "results": [
                    {
                        "code": "12",
                        "date": datetime.datetime(2015, 6, 8, 9, 26, 49),
                        "flags": ["1-3ET[A]"],
                        "instrument": "star1tac",
                        "status": "1",
                        "unit": "",
                        "value": "0.50",
                    }
                ],
            },
            {
                "control_lot": "12047112617",
                "results": [
                    {
                        "code": "12",
                        "date": datetime.datetime(2015, 6, 8, 9, 27, 15),
                        "flags": ["2-2ET[A]", "1-3ET[A]", "R-4ET[A]"],
                        "instrument": "star1tac",
                        "status": "1",
                        "unit": "",
                        "value": "3",
                    }
                ],
                "sample_id": "12047112617",
                "type": "control",
            },
        ],
    }
    assert worklist == expected


def test_decode_trop_vieux(self):
    self.configure(ignore_fichier_n_jour=3)
    worklist = self.decode(
        """
    H|\\^&|||^1.00|||||||||20150608122138
    O|1|12046112617
    R|1|^^^12|0.50|||||||||20150608092649|star1tac
    S|1|||||I^1-3ET[A]^1^997002^
    L|1|N"""
    )
    assert not worklist.samples
