# -*- coding: utf8 -*-
from __future__ import unicode_literals

import copy

parser_class = "cytovision"


def unindent(data):
    return "".join(
        [li.lstrip().replace("\t", "") for li in data.splitlines() if li.strip()]
    )


def test_order(self):
    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0].results.add(
        code="DATE test,Date,100", value="20150131", anterior=False
    )
    message = self.order(worklist=worklist)
    expected = unindent(
        """
    <?xml version="1.0" encoding="UTF-8"?>
    <CWS>
        <Case name="123456">
            <CaseDetailsSet>
                <CaseDetail ctrltype="Date" editable="True" mandatory="False" text="13/05/2013" title="Date du dossier" type="system" />
                <CaseDetail ctrltype="Text" editable="True" mandatory="False" text="NYME" title="Nom" type="system" />
                <CaseDetail ctrltype="Text" editable="True" mandatory="False" text="NJF" title="Nom de naissance" type="system" />
                <CaseDetail ctrltype="Text" editable="True" mandatory="False" text="ANO" title="Prenom" type="system" />
                <CaseDetail ctrltype="Date" editable="True" mandatory="False" text="13/05/2011" title="Date de naissance" type="system" />
                <CaseDetail ctrltype="Text" editable="True" mandatory="False" text="42" title="A" type="system" />
                <CaseDetail ctrltype="Text" editable="True" mandatory="False" text="" title="B" type="system" />
                <CaseDetail ctrltype="Date" editable="True" mandatory="False" text="31/01/2015" title="DATE test" type="system" />
            </CaseDetailsSet>
        </Case>
        </CWS>
    """
    )
    assert message == expected


def test_resultat(self):
    worklist = self.decode(
        """
    <?xml version="1.0" encoding="UTF-8"?>
    <CWS>
        <Case name="CD0419059HY" foldername="CD0419059HY">
        <CaseDetailsSet>
            <CaseDetail title="Nom" text="TEST" type="system" ctrltype="Text" editable="True" mandatory="False" />
            <CaseDetail title="Nom de naissance" text="" type="system" ctrltype="Text" editable="True" mandatory="False" />
            <CaseDetail title="Prenom" text="CLARA" type="system" ctrltype="Text" editable="True" mandatory="False" />
            <CaseDetail title="Date de naissance" text="01/01/1980 00:00:00" type="system" ctrltype="Date" editable="True" mandatory="False" />
            <CaseDetail title="Resolution" text="550" type="system" ctrltype="Number" editable="True" mandatory="False" />
            <CaseDetail title="Nombre de cellules etudiees" text="105" type="system" ctrltype="Number" editable="True" mandatory="False" />
            <CaseDetail title="Nombre de cellules caryotypees" text="8" type="system" ctrltype="Number" editable="True" mandatory="False" />
            <CaseDetail title="FISH : Nombre de metaphases analysees" text="18" type="system" ctrltype="Number" editable="True" mandatory="False" />
            <CaseDetail title="FISH : Nombre de noyaux analyses" text="250" type="system" ctrltype="Number" editable="True" mandatory="False" />
            <CaseDetail title="Formule chromosomique" text="46,XX.ish Xp11.1q11.1(DXZ1x2).nuc ish(DXZ1x2)                                                                      " type="system" ctrltype="MultiLineText" editable="True" mandatory="False" />
            <CaseDetail title="Rendu par" text="AP                                                                     " type="system" ctrltype="Text" editable="True" mandatory="False" />
            <CaseDetail title="Commentaire(s) libre(s)" text="Commentaire libre" type="system" ctrltype="Text" editable="True" mandatory="False" />
        </CaseDetailsSet>
        <Flag title="Completed" />
        <CaseSummary karyotyped="0" counted="0" male="0" female="0" analysed="0" processed="0" colonies="0" />
        </Case>
    </CWS>
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {"code": "Resolution", "value": "550"},
                    {"code": "Nombre de cellules etudiees", "value": "105"},
                    {"code": "Nombre de cellules caryotypees", "value": "8"},
                    {"code": "FISH : Nombre de metaphases analysees", "value": "18"},
                    {"code": "FISH : Nombre de noyaux analyses", "value": "250"},
                    {
                        "code": "Formule chromosomique",
                        "value": "46,XX.ish Xp11.1q11.1(DXZ1x2).nuc " "ish(DXZ1x2)",
                    },
                    {"code": "Rendu par", "value": "AP"},
                    {"code": "Commentaire(s) libre(s)", "value": "Commentaire libre"},
                    {"code": "Flag", "value": "Completed"},
                ],
                "sample_id": "CD0419059HY",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_result_with_bom(self):
    worklist = self.decode(
        """
    ﻿<?xml version="1.0" encoding="utf-8"?>
    <CWS>
    <Case name="18000M23270018" foldername="18000M23270018">
        <CaseDetailsSet>
        <CaseDetail title="Date du dossier" text="23/11/2022 00:00:00" type="system" ctrltype="Date" editable="True" mandatory="False" />
        <CaseDetail title="Nom" text="TEST" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="Nom de naissance" text="" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="Prenom" text="Form Melanie" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="Date de naissance" text="21/09/1983 00:00:00" type="system" ctrltype="Date" editable="True" mandatory="False" />
        <CaseDetail title="Date de prélèvement" text="23/11/2022 00:00:00" type="system" ctrltype="Date" editable="True" mandatory="False" />
        <CaseDetail title="Indication" text="Troubles de la reproduction : infertilité" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="Nombre de métaphases analysées" text="16" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="Nombre de métaphases caryotypées" text="6" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="Formule chromosomique" text="46,XXHFOHAZFNKQ,(()[]nklhflz4581" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="FISH1 : Nb de métaphases analysées" text="14" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="FISH1 : Nb de noyaux analysés" text="235" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="FISH2 : Nb de métaphases analysées" text="18" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="FISH2 : Nb de noyaux analysés" text="291" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="FISH3 : Nb de métaphases analysées" text="15" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="FISH3 : Nb de noyaux analysés" text="260" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="FISH4 : Nb de métaphases analysées" text="45" type="system" ctrltype="Text" editable="True" mandatory="False" />
        <CaseDetail title="FISH4 : Nb de noyaux analysés" text="345" type="system" ctrltype="Text" editable="True" mandatory="False" />
        </CaseDetailsSet>
        <Flag title="Completed" />
        <CaseSummary karyotyped="12" counted="31" male="30" female="0" analysed="30" processed="0" colonies="0" />
    </Case>
    </CWS>
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {"code": "Date du dossier", "value": "23/11/2022 00:00:00"},
                    {"code": "Date de prélèvement", "value": "23/11/2022 00:00:00"},
                    {
                        "code": "Indication",
                        "value": "Troubles de la reproduction : " "infertilité",
                    },
                    {"code": "Nombre de métaphases analysées", "value": "16"},
                    {"code": "Nombre de métaphases caryotypées", "value": "6"},
                    {
                        "code": "Formule chromosomique",
                        "value": "46,XXHFOHAZFNKQ,(()[]nklhflz4581",
                    },
                    {"code": "FISH1 : Nb de métaphases analysées", "value": "14"},
                    {"code": "FISH1 : Nb de noyaux analysés", "value": "235"},
                    {"code": "FISH2 : Nb de métaphases analysées", "value": "18"},
                    {"code": "FISH2 : Nb de noyaux analysés", "value": "291"},
                    {"code": "FISH3 : Nb de métaphases analysées", "value": "15"},
                    {"code": "FISH3 : Nb de noyaux analysés", "value": "260"},
                    {"code": "FISH4 : Nb de métaphases analysées", "value": "45"},
                    {"code": "FISH4 : Nb de noyaux analysés", "value": "345"},
                    {"code": "Flag", "value": "Completed"},
                ],
                "sample_id": "18000M23270018",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected
