# -*- coding: utf8 -*-

from __future__ import unicode_literals

import datetime

parser_class = "elite_astm"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&|||MCA|||||||P|1|20130715141912
    P|1|123456|123456||NYME ANO||20110513|F
    O|1|123456||^^^A|R||||||||||||||||||||O
    O|2|123456||^^^B|R||||||||||||||||||||O
    L|1|N"""
    assert message == expected


def test_decode_query(self):
    worklist = self.decode(
        """
    H|\\^&|||MCA|||||||P|1|20130709113653
    Q|1|^ALL||||||||O
    L|1|N"""
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "ALL"}],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        b"""
    H|\\^&|||2071408B0011E^^V1.1|||||||P|1|20150724150947
    P|1||1234|||||||||||||||||||||||||||||||
    O|1|||^^^CMV|||||||||||||||||||||F|||||
    R|1|^^^7^MGB Alert ASR-CMV|CMV:DNA Not detected or below 1IU_mL(Ch=1Target=CMV1.544900e-02)(Ch=2 Target=IC20.000000e+00)| IU/mL||||F||ServicePSS|20150724121229|20150724145829|2071408B0011E
    L|1|N""".decode(
            self.parser.ENCODING
        )
    )
    date = datetime.datetime(2015, 7, 24, 14, 58, 29)
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "1234",
                "type": "patient",
                "results": [
                    {
                        "code": "CMV",
                        "date": date,
                        "value": "DNA Not detected or below 1IU_mL(Ch=1Target=CMV1.544900e-02)(Ch=2 Target=IC20.000000e+00)",
                        "instrument": "2071408B0011E",
                    }
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_qc_prefix(self):
    self.configure(qc_prefix="CQ")
    worklist = self.decode(
        """
    H|\\^&|||2071408B0011E^^V1.1|||||||P|1|20150724150947
    P|1||CQ1234|||||||||||||||||||||||||||||||
    O|1|||^^^CMV|||||||||||||||||||||F|||||
    R|1|^^^7^MGB Alert ASR-CMV|CMV:20.000000e+00| IU/mL||||F||ServicePSS|20150724121229|20150724145829|2071408B0011E
    L|1|N"""
    )
    date = datetime.datetime(2015, 7, 24, 14, 58, 29)
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "sample_id": "CQ1234",
                "control_lot": "CQ1234",
                "results": [
                    {
                        "code": "CMV",
                        "date": date,
                        "value": "20.000000e+00",
                        "instrument": "2071408B0011E",
                    }
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_result_13(self):
    worklist = self.decode(
        """
        H|\\^&|||^2071903B0393E^V1.3|||||||P|1|20210302085833
        P|1|||||||||||||||||||||||||||||||||
        O|1|09210610198^^||^^^SARSCoV2_G^1.0|||||||||||||||||||||F|||||
        R|1|^^^3^^SARSCoV2_G|^ORF8:SARS CoV 2 ARN non détecté ou inférieur à LoD\\RdRp:SARS CoV 2 ARN non détecté ou inférieur à LoD|||||F||VIDJEACOUMARANE||20210301200804|
        L|1|N"""
    )
    date = datetime.datetime(2021, 3, 1, 20, 8, 4)
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "09210610198",
                "type": "patient",
                "results": [
                    {
                        "code": "ORF8",
                        "date": date,
                        "value": "SARS CoV 2 ARN non détecté ou inférieur à LoD",
                        "instrument": "",
                    },
                    {
                        "code": "RdRp",
                        "date": date,
                        "value": "SARS CoV 2 ARN non détecté ou inférieur à LoD",
                        "instrument": "",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_index_result_13(self):
    worklist = self.decode(
        """
        H|\\^&|||^2071602B0063E^V1.3|||||||P|1|20220228121050
        P|1|||||||||||||||||||||||||||||||||
        O|1|440202242027^^||^^^CMV_WB^1.0|||||||||||||||||||||F|||||
        R|1|^^^4^CMV^CMV_WB|4512^CMV:DNA Detected, quantity equal to 4512gEq/mL|gEq/mL||D||F||ANAIS 52||20220226212252|
        L|1|N
        """
    )
    date = datetime.datetime(2022, 2, 26, 21, 22, 52)
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {
                        "code": "CMV",
                        "date": date,
                        "instrument": "",
                        "value": "DNA Detected, quantity equal to " "4512gEq/mL",
                    },
                    {"code": "CMV_I", "value": "4512"},
                ],
                "sample_id": "440202242027",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected
