# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

import pytest

from driverng import MessageV2, Worklist
from driverng.tests import BaseTest


def test_empty_samples():
    wk = Worklist(
        [
            {
                "sample_id": "123456",
                "patient_id": "55555",
                "orders": [{"code": "A", "action": "del", "priority": "R"}],
            }
        ]
    ).get_astm_worklist(
        unique_together=["action"], action={"del": Worklist.IGNORE, Worklist.ELSE: None}
    )
    assert wk == []


def test_sample_with_date():
    date = datetime.datetime(2014, 8, 19, 15, 58, 13, 343000)
    wk = Worklist(samples=[{"collection_date": date}])
    expected = """{"samples": [{"collection_date": "2014-08-19T15:58:13.343"}]}"""
    assert wk.dumps() == expected
    assert Worklist.loads(expected) == wk


def test_worklist_create():
    wk = Worklist(context="result")
    sample = wk.get_or_create(sample_id="1234", type="patient")
    sample = wk.get_or_create(sample_id="1234", type="patient")
    wk.validate()
    assert len(wk.samples) == 1
    result = sample.results.add(code="TEST", value="42")
    wk.validate()
    result.typo = "fail"
    with pytest.raises(Worklist.ValidationError):
        wk.validate()


def test_worklist_encode_decode():
    worklist = BaseTest.WORKLIST_NEW_ADD_DEL
    assert worklist == Worklist.loads(worklist.dumps())


def test_get_order_message_empty_sample():
    # Une worklist legacy vide qui passe dans get_order_message doit sortir
    # avec un context "order"
    class M(MessageV2):
        def encode_worklist(self, worklist, context):
            self._test_worklist = worklist

    m = M()
    m.get_order_message(Worklist([]), {})
    worklist = m._test_worklist
    expected = {"context": "order", "samples": []}
    assert worklist == expected
